@@ -1,10 +1,11 @@
+from functools import partial
 from pathlib import Path
 
 inited = False
 root = None
 
 
-def init(func):
+def init_theme(func):
     def wrapper(*args, **kwargs):
         global inited
         global root
@@ -12,14 +13,14 @@ def init(func):
         if not inited:
             from tkinter import _default_root
 
-            path = (Path(__file__).parent / "sun-valley.tcl").resolve()
+            path = (Path(__file__).parent / "sv.tcl").resolve()
 
             try:
                 _default_root.tk.call("source", str(path))
             except AttributeError:
                 raise RuntimeError(
-                    "can't set theme. Tk is not initialized. "
-                    + "Please first create a tkinter.Tk instance, then set the theme."
+                    "can't set theme, because tkinter is not initialized. "
+                    + "Please create a tkinter.Tk instance first and then set the theme."
                 ) from None
             else:
                 inited = True
@@ -30,31 +31,28 @@ def init(func):
     return wrapper
 
 
-@init
+@init_theme
 def set_theme(theme):
     if theme not in {"dark", "light"}:
-        raise RuntimeError(f"not a valid theme name: {theme}")
+        raise RuntimeError("not a valid theme name: {}".format(theme))
 
     root.tk.call("set_theme", theme)
 
 
-@init
+@init_theme
 def get_theme():
     theme = root.tk.call("ttk::style", "theme", "use")
 
-    try:
-        return {"sun-valley-dark": "dark", "sun-valley-light": "light"}[theme]
-    except KeyError:
-        return theme
+    return {"sun-valley-dark": "dark", "sun-valley-light": "light"}.get(theme, theme)
 
 
-@init
+@init_theme
 def toggle_theme():
-    if get_theme() == "dark":
-        use_light_theme()
-    else:
+    if get_theme() == "light":
         use_dark_theme()
+    else:
+        use_light_theme()
 
 
-use_dark_theme = lambda: set_theme("dark")
-use_light_theme = lambda: set_theme("light")
+use_dark_theme = partial(set_theme, "dark")
+use_light_theme = partial(set_theme, "light")
